package com.sooka.system.mapper;


import com.sooka.system.domain.SysDept;

/**
 * 【系统首页】Mapper接口
 *
 * @author wangzhe
 * @date 2023-06-27
 */
public interface SysIndexMapper {

    /**
     * 查询接口数量
     */
    public Integer getInterfaceCountAll();
    /**
     * 查询接口故障
     */
    public Integer getInterfaceCountError();

    /**
     * 接口调用频次
     */
    public Long callFrequency();
    /**
     * 接口归集频次
     */
    public Long pushFrequency();
    /**
     * 接口共享频次
     */
    public Long pullFrequency();

    /**
     * 查询接入部门
     */
    public Integer joinUpDepts(SysDept sysDept);

}
